==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.md <==
# AmazonSimpleStorageServiceS3StorageLens


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')
```



| Illustration | AmazonSimpleStorageServiceS3StorageLens | AmazonSimpleStorageServiceS3StorageLensCard | AmazonSimpleStorageServiceS3StorageLensGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLens](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.Local.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLensCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLensCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLensGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLensGroup.Local.png) |




## AmazonSimpleStorageServiceS3StorageLens

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLens
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLens('AmazonSimpleStorageServiceS3StorageLens', 'Amazon Simple Storage Service S3 Storage Lens', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLens
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLens('AmazonSimpleStorageServiceS3StorageLens', 'Amazon Simple Storage Service S3 Storage Lens', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3StorageLensCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensCard('AmazonSimpleStorageServiceS3StorageLensCard', 'Amazon Simple Storage Service S3 Storage Lens Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensCard('AmazonSimpleStorageServiceS3StorageLensCard', 'Amazon Simple Storage Service S3 Storage Lens Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3StorageLensGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensGroup('AmazonSimpleStorageServiceS3StorageLensGroup', 'Amazon Simple Storage Service S3 Storage Lens Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensGroup('AmazonSimpleStorageServiceS3StorageLensGroup', 'Amazon Simple Storage Service S3 Storage Lens Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.md <==
# AmazonSimpleStorageServiceS3StorageLens


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')
```



| Illustration | AmazonSimpleStorageServiceS3StorageLens | AmazonSimpleStorageServiceS3StorageLensCard | AmazonSimpleStorageServiceS3StorageLensGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLens](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens.Local.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLensCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLensCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3StorageLensGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLensGroup.Local.png) |




## AmazonSimpleStorageServiceS3StorageLens

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLens
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLens('AmazonSimpleStorageServiceS3StorageLens', 'Amazon Simple Storage Service S3 Storage Lens', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLens
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLens('AmazonSimpleStorageServiceS3StorageLens', 'Amazon Simple Storage Service S3 Storage Lens', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3StorageLensCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensCard('AmazonSimpleStorageServiceS3StorageLensCard', 'Amazon Simple Storage Service S3 Storage Lens Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensCard('AmazonSimpleStorageServiceS3StorageLensCard', 'Amazon Simple Storage Service S3 Storage Lens Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3StorageLensGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensGroup('AmazonSimpleStorageServiceS3StorageLensGroup', 'Amazon Simple Storage Service S3 Storage Lens Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3StorageLensGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3StorageLens')

' renders the element
AmazonSimpleStorageServiceS3StorageLensGroup('AmazonSimpleStorageServiceS3StorageLensGroup', 'Amazon Simple Storage Service S3 Storage Lens Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
